#[non_exhaustive]pub enum Error {
BadCryptoStoreState,
EncryptionNotEnabled,
StateStore(StoreError),
EventCacheStore(EventCacheStoreError),
EventCacheLock(CrossProcessLockError),
CryptoStore(CryptoStoreError),
OlmError(OlmError),
MegolmError(MegolmError),
InvalidReceiveMembersParameters,
InsufficientData,
DeserializationError(Error),
}Expand description
Internal representation of errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BadCryptoStoreState
e2e-encryption only.Attempting to restore a session after the olm-machine has already been set up fails
EncryptionNotEnabled
e2e-encryption only.The room where a group session should be shared is not encrypted.
StateStore(StoreError)
A generic error returned when the state store fails not due to IO or (de)serialization.
EventCacheStore(EventCacheStoreError)
An error happened while manipulating the event cache store.
EventCacheLock(CrossProcessLockError)
An error happened while attempting to lock the event cache store.
CryptoStore(CryptoStoreError)
e2e-encryption only.An error occurred in the crypto store.
OlmError(OlmError)
e2e-encryption only.An error occurred during a E2EE operation.
MegolmError(MegolmError)
e2e-encryption only.An error occurred during a group E2EE operation.
InvalidReceiveMembersParameters
An error caused by calling the BaseClient::receive_all_members
function with invalid parameters
InsufficientData
This request failed because the local data wasn’t sufficient.
DeserializationError(Error)
There was a serde_json deserialization error.