IntoEventCacheStore

Trait IntoEventCacheStore 

pub trait IntoEventCacheStore { }
A type that can be type-erased into Arc<dyn EventCacheStore>.

This trait is not meant to be implemented directly outside matrix-sdk-base, but it is automatically implemented for everything that implements EventCacheStore.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoEventCacheStore for Arc<DynEventCacheStore>

Source

impl<T> IntoEventCacheStore for Arc<T>
where T: EventCacheStore + 'static,

Implementors

Source

impl<T> IntoEventCacheStore for T
where T: EventCacheStore + Sized + 'static,