#[non_exhaustive]pub enum TimelineEventType {
Show 56 variants
CallAnswer,
CallInvite,
CallHangup,
CallCandidates,
CallNegotiate,
CallReject,
CallSdpStreamMetadataChanged,
CallSelectAnswer,
KeyVerificationReady,
KeyVerificationStart,
KeyVerificationCancel,
KeyVerificationAccept,
KeyVerificationKey,
KeyVerificationMac,
KeyVerificationDone,
Location,
Message,
PollStart,
UnstablePollStart,
PollResponse,
UnstablePollResponse,
PollEnd,
UnstablePollEnd,
Beacon,
Reaction,
RoomEncrypted,
RoomMessage,
RoomRedaction,
Sticker,
CallNotify,
RtcNotification,
RtcDecline,
PolicyRuleRoom,
PolicyRuleServer,
PolicyRuleUser,
RoomAvatar,
RoomCanonicalAlias,
RoomCreate,
RoomEncryption,
RoomGuestAccess,
RoomHistoryVisibility,
RoomJoinRules,
RoomMember,
RoomName,
RoomPinnedEvents,
RoomPolicy,
RoomPowerLevels,
RoomServerAcl,
RoomThirdPartyInvite,
RoomTombstone,
RoomTopic,
SpaceChild,
SpaceParent,
BeaconInfo,
CallMember,
MemberHints,
}Expand description
The type of TimelineEvent this is.
This type can hold an arbitrary string. To build events with a custom type, convert it
from a string with ::from() / .into(). To check for events that are not available as a
documented variant here, use its string representation, obtained through .to_string().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CallAnswer
m.call.answer
CallInvite
m.call.invite
CallHangup
m.call.hangup
CallCandidates
m.call.candidates
CallNegotiate
m.call.negotiate
CallReject
m.call.reject
CallSdpStreamMetadataChanged
m.call.sdp_stream_metadata_changed
This variant can also be deserialized from the org.matrix.call.sdp_stream_metadata_changed type.
CallSelectAnswer
m.call.select_answer
KeyVerificationReady
m.key.verification.ready
KeyVerificationStart
m.key.verification.start
KeyVerificationCancel
m.key.verification.cancel
KeyVerificationAccept
m.key.verification.accept
KeyVerificationKey
m.key.verification.key
KeyVerificationMac
m.key.verification.mac
KeyVerificationDone
m.key.verification.done
Location
unstable-msc3488 only.m.location
Message
unstable-msc1767 only.m.message
This variant uses the unstable type org.matrix.msc1767.message.
This variant can also be deserialized from the m.message type.
PollStart
unstable-msc3381 only.m.poll.start
UnstablePollStart
unstable-msc3381 only.org.matrix.msc3381.poll.start
PollResponse
unstable-msc3381 only.m.poll.response
UnstablePollResponse
unstable-msc3381 only.org.matrix.msc3381.poll.response
PollEnd
unstable-msc3381 only.m.poll.end
UnstablePollEnd
unstable-msc3381 only.org.matrix.msc3381.poll.end
Beacon
unstable-msc3489 only.m.beacon
This variant uses the unstable type org.matrix.msc3672.beacon.
This variant can also be deserialized from the m.beacon type.
Reaction
m.reaction
RoomEncrypted
m.room.encrypted
RoomMessage
m.room.message
RoomRedaction
m.room.redaction
Sticker
m.sticker
CallNotify
unstable-msc4075 only.m.call.notify
This variant uses the unstable type org.matrix.msc4075.call.notify.
This variant can also be deserialized from the m.call.notify type.
RtcNotification
unstable-msc4075 only.m.rtc.notification
This variant uses the unstable type org.matrix.msc4075.rtc.notification.
This variant can also be deserialized from the m.rtc.notification type.
RtcDecline
unstable-msc4310 only.m.rtc.decline
This variant uses the unstable type org.matrix.msc4310.rtc.decline.
This variant can also be deserialized from the m.rtc.decline type.
PolicyRuleRoom
m.policy.rule.room
PolicyRuleServer
m.policy.rule.server
PolicyRuleUser
m.policy.rule.user
RoomAvatar
m.room.avatar
RoomCanonicalAlias
m.room.canonical_alias
RoomCreate
m.room.create
RoomEncryption
m.room.encryption
RoomGuestAccess
m.room.guest_access
RoomHistoryVisibility
m.room.history_visibility
RoomJoinRules
m.room.join_rules
RoomMember
m.room.member
RoomName
m.room.name
RoomPinnedEvents
m.room.pinned_events
RoomPolicy
m.room.policy
RoomPowerLevels
m.room.power_levels
RoomServerAcl
m.room.server_acl
RoomThirdPartyInvite
m.room.third_party_invite
RoomTombstone
m.room.tombstone
RoomTopic
m.room.topic
SpaceChild
m.space.child
SpaceParent
m.space.parent
BeaconInfo
unstable-msc3489 only.m.beacon_info
This variant uses the unstable type org.matrix.msc3672.beacon_info.
This variant can also be deserialized from the m.beacon_info type.
CallMember
unstable-msc3401 only.m.call.member
This variant uses the unstable type org.matrix.msc3401.call.member.
This variant can also be deserialized from the m.call.member type.
MemberHints
unstable-msc4171 only.m.member_hints
This variant uses the unstable type io.element.functional_members.
This variant can also be deserialized from the m.member_hints type.