pub struct IncorrectMutexGuardError;Expand description
An error type that represents a scenario where a MutexGuard provided to
a function does not reference the underlying Mutex in the enclosing
SaveLockedStateStore.