pub trait IntoEventCacheStore { }Expand description
A type that can be type-erased into Arc<dyn EventCacheStore>.
This trait is not meant to be implemented directly outside
matrix-sdk-base, but it is automatically implemented for everything that
implements EventCacheStore.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".